==> CGFeedMaker-1.0.14.tar.gz: CGFeedMaker/lang/ext/it_IT.php <==
<?php
$lang['addcategory'] = 'Aggiungere una nuova Categoria';
$lang['addedit_feed'] = 'Aggiungere/Modificare RSS Feed';
$lang['addfeed'] = 'Aggiungere un nuovo RSS Feed';
$lang['areyousure_delete'] = 'Siete sicuri di voler cancellare questo termine?';
$lang['cancel'] = 'Cancella';
$lang['categories'] = 'Categorie';
$lang['current_value'] = 'Valore corrente';
$lang['delete'] = 'Cancella';
$lang['details'] = 'Dettagli';
$lang['edit'] = 'Modifica';
$lang['error_missingparam'] = 'Non &egrave; stato trovato un parametro richiesto o un valore';
$lang['error_nameexists'] = 'Un termine con questo nome gi&agrave; esiste';
$lang['error_nocatname'] = 'Si prega di specificare un nome di Categoria';
$lang['error_nonamegiven'] = 'Dovete inserire un nome/alias al RSS Feed';
$lang['error_nopermission'] = 'Permesso negato';
$lang['error_notemplate'] = 'Nessun Modello inserito';
$lang['feeds'] = 'Feed';
$lang['feed_copyright'] = 'Copyright del Feed';
$lang['feed_description'] = 'Feed Descrizione';
$lang['feed_editor'] = 'Editor per i Feed';
$lang['feed_extension'] = 'Estensioni Feed';
$lang['feed_image'] = 'Feed Immagine';
$lang['feed_link'] = 'Link del Feed';
$lang['feed_namealias'] = 'Feed Nome/Alias';
$lang['feed_pageid'] = 'Usa questa pagina per i links';
$lang['feed_title'] = 'Feed Titolo';
$lang['feed_ttl'] = 'Tempo di vita del RSS Feed';
$lang['friendlyname'] = 'Calguys Feed Maker ';
$lang['help'] = '<h3>What Does This Do?</h3>
<p>This module provides the ability to build and manage RSS Feeds consisting of data from any CMS Made Simple module that supports a summary view.</p>
<p>It supports categorizing the feeds, generating auto-discovery links, and standalone links to rss feeds.</p>
<p>Pretty URL&#039;s are supported if your site has them enabled. - <em>ex:</em> http://www.yoursite.com/feeds/Feed-Name</p>
<h3>How Do I Use It?</h3>
<ul>
<li>-First you must create a new feed, and fill in the parameters supplied.
  <p>A template is associated with each feed.  The default template illustrates how to generate an RSS feed from the News module</p>
  <p>To generate templates from other feeds you will need to use the template variables from that module. Put {get_template_vars} in a page that uses that module to see which variables you can call into your Feed Template. To control the output of your feed you need to use a combination of these template variables and modify your module call in the template.</p>
</li>
<li>-Secondly you should place an auto-discovery tag in the appropriate place.
  <p>This will create auto-discovery links in your output.  You can place this tag in the head section of the page template, or the metadata section of specific pages to generate autodiscovery.  Various parameters can be specified to control which feeds auto-discovery links are generated for.<br /></p>
<p>  
<em>ex1:</em> <strong>{CGFeedMaker action=&#039;autodiscovery&#039; feed=&#039;myFeed1,myFeed2 &#039;}</strong> - This creates autodiscovery links for all specified feeds<br />
<em>ex2:</em> <strong>{CGFeedMaker action=&#039;autodiscovery&#039; category=&#039;myCategory1,myCategory2&#039;}</strong> - This creates autodiscovery links for all feeds in the specified category or categories</p>
</li>
  <li>-Thirdly, you can place links to specific feeds in your content.  using the action=rsslink parameter.<p>This will create a link to the specified feed in the location you put the call.</p>
  <p><em>ex1:</em> <strong>{CGFeedMaker action=&#039;rsslink&#039; feed=&#039;myfeed&#039;}</strong> - Generic &quot;rsslink&quot; call
  <br/>
  <em>ex2:</em> <strong>{CGFeedMaker action=&#039;rsslink&#039; feed=&#039;myfeed&#039; imageonly=&#039;&#039; image=&#039;uploads/images/rssNew.jpg&#039; imageclass=&#039;rssImage&#039;}</strong> - This call displays a link that shows only an Image for the link, it specifies a different image that was uploaded to use for the link than the default image and it uses a different CSS class to format the image (specified in one of your stylesheets)  
  <br />
   <em>ex3:</em> <strong>{CGFeedMaker action=&#039;rsslink&#039; feed=&#039;myfeed&#039; text=&#039;RSS News Feed&#039; image=&#039;uploads/images/rssNew.jpg&#039; imageclass=&#039;rssImage&#039; linkclass=&quot;rssLink&quot;}</strong> - This call specifies different text for the link to the feed, specifies a new image to be used and uses different CSS classes to format the Image and Link (specified in one of your stylesheets)   </p> 
  </ul>
<h3>Notes:</h3>
<ul>
<li>This module will work best, and the default feeds will validate if you have configured pretty urls properly.   Otherwise, atom links seem to have problems with some of our URLS.</li>
</ul>
<h3>Support</h3>
<p>This module does not include commercial support. However, there are a number of resources available to help you with it:</p>
<ul>
<li>For the latest version of this module, FAQs, or to file a Bug Report or buy commercial support, please visit calguy&#039;s
homepage at <a href="http://calguy1000.com">calguy1000.com</a>.</li>
<li>Additional discussion of this module may also be found in the <a href="http://forum.cmsmadesimple.org">CMS Made Simple Forums</a>.</li>
<li>The author, calguy1000, can often be found in the <a href="irc://irc.freenode.net/#cms">CMS IRC Channel</a>.</li>
<li>Lastly, you may have some success emailing the author directly.</li>  
</ul>
<h3>Copyright and License</h3>
<p>Copyright &amp;copy; 2008, Robert Campbel <a href="mailto:calguy1000@cmsmadesimple.org">&amp;lt;calguy1000@cmsmadesimple.org&amp;gt;</a>. All Rights Are Reserved.</p>
<p>This program is free software; you can redistribute it and/or modify
it under the terms of the GNU General Public License as published by
the Free Software Foundation; either version 2 of the License, or
(at your option) any later version.</p>
<p>However, as a special exception to the GPL, this software is distributed
as an addon module to CMS Made Simple.  You may not use this software
in any Non GPL version of CMS Made simple, or in any version of CMS
Made simple that does not indicate clearly and obviously in its admin 
section that the site was built with CMS Made simple.</p>
<p>This program is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
GNU General Public License for more details.
You should have received a copy of the GNU General Public License
along with this program; if not, write to the Free Software
Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307 USA
Or read it <a href="http://www.gnu.org/licenses/licenses.html#GPL">online</a></p>';
$lang['info_alias'] = 'Questo RSS feed deve contenere solo caratteri che sono adeguati in un URL';
$lang['info_copyright'] = 'Nota di Copyright per il contenuto di questo canale';
$lang['info_description'] = 'Una frase o parla che descriva questo canale';
$lang['info_editor'] = 'Indirizzo Email dell&#039;editore di questo canale';
$lang['info_extension'] = 'Estensione Feed (specifica una estensione per questo feed, p.e. xml,rss,kml... se non specificata sar&agrave; usata la estensione predefinita rss';
$lang['info_feed_extension'] = 'Quando usi mod_rewrite per formare pretty urls questo parametro pu&ograve; essere usato per specificare la estensione del feed generato.';
$lang['info_image'] = 'Specifica una immagine GIF, JPEG o PNG che possono essere visualizzate con questo canale';
$lang['info_link'] = 'L&#039;indirizzo URL del sito web corrispondente a questo canale';
$lang['info_pageid'] = 'La pagina che dovrebbe essere usata per tutti i link in questo RSS feed';
$lang['info_ttl'] = 'numero di minuti che indica quanto un canale dovrebbe essere in cache prima di rinfrescare dal sorgente';
$lang['moddescription'] = 'Un tool flessibile per la creazione e la gestione di RSS feeds';
$lang['name'] = 'Nome';
$lang['param_action'] = 'Specifica il comportamento del modulo. Cis ono due valori possibili per questo parametro &quot;autodiscovery&quot; e &quot;rsslink&quot;. L&#039;azione di autodiscovery generer&agrave; degli auto discovery link e dovrebbe essere usato per farli apparire nella sezione head della Vostra pagina.  L&#039;azione di rsslink pu&ograve; essere usata per creare un link ad uno specifico feed e pu&ograve; essere posto nel content della Vostra pagina';
$lang['param_category'] = 'Utile solo con l&#039;azione autodiscovery, questo parametro Vi permette di specificare una lista separata da virgole di categorie di feed che controlleranno quali feeds links saranno generati';
$lang['param_feed'] = 'Utile con le azioni rsslink e autodiscovery, questo parametro Vi permette di specificare quali feed genereranno un link. Con l&#039;azione autodiscovery, pu&ograve; essere inserita una lista separata da virgole di nomi di RSS feed.';
$lang['param_image'] = 'Utile solo con l&#039;azione rsslink, questo parametro Vi permette di specificare una differente immagine per i link del RSS feed';
$lang['param_imageclass'] = 'Specifica una classe CSS da inserire nel tag immagine di un RSS feed link';
$lang['param_imageonly'] = 'Utile solo con l&#039;azione rsslink, questo parametro Vi permette di specificare che nessun testo dovrebbe uscire con il link';
$lang['param_linkclass'] = 'Specifica una classe CSS da inserire nel tag link di un RSS feed link';
$lang['param_urlonly'] = 'Applicabile solo all&#039;azione rsslink, questo parametro richiede che il codice visualizza solo l&#039;url al feed RSS';
$lang['param_text'] = 'Utile solo con l&#039;azione rsslink, questo parametro Vi permette di specificare il testo che dovrebbe essere associato con il link. Se il parametro non &egrave; specificato, sar&agrave; usato il titolo del feed RSS';
$lang['postinstall'] = 'Il modulo CGFeedMaker &egrave; stato installato con successo';
$lang['postuninstall'] = 'Il modulo CGFeedMaker Module e tutti i dati associati sono stati rimossi';
$lang['really_uninstall'] = 'Siete sicuri di voler rimuovere questo modulo. Tutti i dati associati con questo modulo verranno rimossi';
$lang['reset_to_factory'] = 'Azzera tutto al predefinito';
$lang['settings'] = 'Configurazioni';
$lang['submit'] = 'Invia';
$lang['template'] = 'Modello';
$lang['template_source'] = 'Sorgente del Modello';
$lang['qca'] = 'P0-250679722-1271187168764';
?>

==> CGFeedMaker-1.0.17.tar.gz: CGFeedMaker/lang/ext/it_IT.php <==
<?php
$lang['addcategory'] = 'Aggiungere una nuova Categoria';
$lang['addedit_feed'] = 'Aggiungere/Modificare RSS Feed';
$lang['addfeed'] = 'Aggiungere un nuovo RSS Feed';
$lang['areyousure_delete'] = 'Siete sicuri di voler cancellare questo termine?';
$lang['cancel'] = 'Cancella';
$lang['categories'] = 'Categorie';
$lang['current_value'] = 'Valore corrente';
$lang['delete'] = 'Cancella';
$lang['details'] = 'Dettagli';
$lang['edit'] = 'Modifica';
$lang['error_missingparam'] = 'Non &egrave; stato trovato un parametro richiesto o un valore';
$lang['error_nameexists'] = 'Un termine con questo nome gi&agrave; esiste';
$lang['error_nocatname'] = 'Si prega di specificare un nome di Categoria';
$lang['error_nonamegiven'] = 'Dovete inserire un nome/alias al RSS Feed';
$lang['error_nopermission'] = 'Permesso negato';
$lang['error_notemplate'] = 'Nessun Modello inserito';
$lang['feeds'] = 'Feed';
$lang['feed_copyright'] = 'Copyright del Feed';
$lang['feed_description'] = 'Feed Descrizione';
$lang['feed_editor'] = 'Editor per i Feed';
$lang['feed_extension'] = 'Estensioni Feed';
$lang['feed_image'] = 'Feed Immagine';
$lang['feed_link'] = 'Link del Feed';
$lang['feed_namealias'] = 'Feed Nome/Alias';
$lang['feed_pageid'] = 'Usa questa pagina per i links';
$lang['feed_title'] = 'Feed Titolo';
$lang['feed_ttl'] = 'Tempo di vita del RSS Feed';
$lang['friendlyname'] = 'Calguys Feed Maker ';
$lang['help'] = '<h3>What Does This Do?</h3>
<p>This module provides the ability to build and manage RSS Feeds consisting of data from any CMS Made Simple module that supports a summary view.</p>
<p>It supports categorizing the feeds, generating auto-discovery links, and standalone links to rss feeds.</p>
<p>Pretty URL&#039;s are supported if your site has them enabled. - <em>ex:</em> http://www.yoursite.com/feeds/Feed-Name</p>
<h3>How Do I Use It?</h3>
<ul>
<li>-First you must create a new feed, and fill in the parameters supplied.
  <p>A template is associated with each feed.  The default template illustrates how to generate an RSS feed from the News module</p>
  <p>To generate templates from other feeds you will need to use the template variables from that module. Put {get_template_vars} in a page that uses that module to see which variables you can call into your Feed Template. To control the output of your feed you need to use a combination of these template variables and modify your module call in the template.</p>
</li>
<li>-Secondly you should place an auto-discovery tag in the appropriate place.
  <p>This will create auto-discovery links in your output.  You can place this tag in the head section of the page template, or the metadata section of specific pages to generate autodiscovery.  Various parameters can be specified to control which feeds auto-discovery links are generated for.<br /></p>
<p>  
<em>ex1:</em> <strong>{CGFeedMaker action=&#039;autodiscovery&#039; feed=&#039;myFeed1,myFeed2 &#039;}</strong> - This creates autodiscovery links for all specified feeds<br />
<em>ex2:</em> <strong>{CGFeedMaker action=&#039;autodiscovery&#039; category=&#039;myCategory1,myCategory2&#039;}</strong> - This creates autodiscovery links for all feeds in the specified category or categories</p>
</li>
  <li>-Thirdly, you can place links to specific feeds in your content.  using the action=rsslink parameter.<p>This will create a link to the specified feed in the location you put the call.</p>
  <p><em>ex1:</em> <strong>{CGFeedMaker action=&#039;rsslink&#039; feed=&#039;myfeed&#039;}</strong> - Generic &quot;rsslink&quot; call
  <br/>
  <em>ex2:</em> <strong>{CGFeedMaker action=&#039;rsslink&#039; feed=&#039;myfeed&#039; imageonly=&#039;&#039; image=&#039;uploads/images/rssNew.jpg&#039; imageclass=&#039;rssImage&#039;}</strong> - This call displays a link that shows only an Image for the link, it specifies a different image that was uploaded to use for the link than the default image and it uses a different CSS class to format the image (specified in one of your stylesheets)  
  <br />
   <em>ex3:</em> <strong>{CGFeedMaker action=&#039;rsslink&#039; feed=&#039;myfeed&#039; text=&#039;RSS News Feed&#039; image=&#039;uploads/images/rssNew.jpg&#039; imageclass=&#039;rssImage&#039; linkclass=&quot;rssLink&quot;}</strong> - This call specifies different text for the link to the feed, specifies a new image to be used and uses different CSS classes to format the Image and Link (specified in one of your stylesheets)   </p> 
  </ul>
<h3>Notes:</h3>
<ul>
<li>This module will work best, and the default feeds will validate if you have configured pretty urls properly.   Otherwise, atom links seem to have problems with some of our URLS.</li>
</ul>
<h3>Support</h3>
<p>This module does not include commercial support. However, there are a number of resources available to help you with it:</p>
<ul>
<li>For the latest version of this module, FAQs, or to file a Bug Report or buy commercial support, please visit calguy&#039;s
homepage at <a href="http://calguy1000.com">calguy1000.com</a>.</li>
<li>Additional discussion of this module may also be found in the <a href="http://forum.cmsmadesimple.org">CMS Made Simple Forums</a>.</li>
<li>The author, calguy1000, can often be found in the <a href="irc://irc.freenode.net/#cms">CMS IRC Channel</a>.</li>
<li>Lastly, you may have some success emailing the author directly.</li>  
</ul>
<h3>Copyright and License</h3>
<p>Copyright &amp;copy; 2008, Robert Campbel <a href="mailto:calguy1000@cmsmadesimple.org">&amp;lt;calguy1000@cmsmadesimple.org&amp;gt;</a>. All Rights Are Reserved.</p>
<p>This program is free software; you can redistribute it and/or modify
it under the terms of the GNU General Public License as published by
the Free Software Foundation; either version 2 of the License, or
(at your option) any later version.</p>
<p>However, as a special exception to the GPL, this software is distributed
as an addon module to CMS Made Simple.  You may not use this software
in any Non GPL version of CMS Made simple, or in any version of CMS
Made simple that does not indicate clearly and obviously in its admin 
section that the site was built with CMS Made simple.</p>
<p>This program is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
GNU General Public License for more details.
You should have received a copy of the GNU General Public License
along with this program; if not, write to the Free Software
Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307 USA
Or read it <a href="http://www.gnu.org/licenses/licenses.html#GPL">online</a></p>
';
$lang['info_alias'] = 'Questo RSS feed deve contenere solo caratteri che sono adeguati in un URL';
$lang['info_copyright'] = 'Nota di Copyright per il contenuto di questo canale';
$lang['info_description'] = 'Una frase o parla che descriva questo canale';
$lang['info_editor'] = 'Indirizzo Email dell&#039;editore di questo canale';
$lang['info_extension'] = 'Estensione Feed (specifica una estensione per questo feed, p.e. xml,rss,kml... se non specificata sar&agrave; usata la estensione predefinita rss';
$lang['info_feed_extension'] = 'Quando usi mod_rewrite per formare pretty urls questo parametro pu&ograve; essere usato per specificare la estensione del feed generato.';
$lang['info_image'] = 'Specifica una immagine GIF, JPEG o PNG che possono essere visualizzate con questo canale';
$lang['info_link'] = 'L&#039;indirizzo URL del sito web corrispondente a questo canale';
$lang['info_pageid'] = 'La pagina che dovrebbe essere usata per tutti i link in questo RSS feed';
$lang['info_ttl'] = 'numero di minuti che indica quanto un canale dovrebbe essere in cache prima di rinfrescare dal sorgente';
$lang['moddescription'] = 'Un tool flessibile per la creazione e la gestione di RSS feeds';
$lang['name'] = 'Nome';
$lang['param_action'] = 'Specifica il comportamento del modulo. Cis ono due valori possibili per questo parametro &quot;autodiscovery&quot; e &quot;rsslink&quot;. L&#039;azione di autodiscovery generer&agrave; degli auto discovery link e dovrebbe essere usato per farli apparire nella sezione head della Vostra pagina.  L&#039;azione di rsslink pu&ograve; essere usata per creare un link ad uno specifico feed e pu&ograve; essere posto nel content della Vostra pagina';
$lang['param_category'] = 'Utile solo con l&#039;azione autodiscovery, questo parametro Vi permette di specificare una lista separata da virgole di categorie di feed che controlleranno quali feeds links saranno generati';
$lang['param_feed'] = 'Utile con le azioni rsslink e autodiscovery, questo parametro Vi permette di specificare quali feed genereranno un link. Con l&#039;azione autodiscovery, pu&ograve; essere inserita una lista separata da virgole di nomi di RSS feed.';
$lang['param_image'] = 'Utile solo con l&#039;azione rsslink, questo parametro Vi permette di specificare una differente immagine per i link del RSS feed';
$lang['param_imageclass'] = 'Specifica una classe CSS da inserire nel tag immagine di un RSS feed link';
$lang['param_imageonly'] = 'Utile solo con l&#039;azione rsslink, questo parametro Vi permette di specificare che nessun testo dovrebbe uscire con il link';
$lang['param_linkclass'] = 'Specifica una classe CSS da inserire nel tag link di un RSS feed link';
$lang['param_urlonly'] = 'Applicabile solo all&#039;azione rsslink, questo parametro richiede che il codice visualizza solo l&#039;url al feed RSS';
$lang['param_text'] = 'Utile solo con l&#039;azione rsslink, questo parametro Vi permette di specificare il testo che dovrebbe essere associato con il link. Se il parametro non &egrave; specificato, sar&agrave; usato il titolo del feed RSS';
$lang['postinstall'] = 'Il modulo CGFeedMaker &egrave; stato installato con successo';
$lang['postuninstall'] = 'Il modulo CGFeedMaker Module e tutti i dati associati sono stati rimossi';
$lang['really_uninstall'] = 'Siete sicuri di voler rimuovere questo modulo. Tutti i dati associati con questo modulo verranno rimossi';
$lang['reset_to_factory'] = 'Azzera tutto al predefinito';
$lang['settings'] = 'Configurazioni';
$lang['submit'] = 'Invia';
$lang['template'] = 'Modello';
$lang['template_source'] = 'Sorgente del Modello';
$lang['utma'] = '156861353.974349155.1299072468.1302003201.1303465107.4';
$lang['qca'] = 'P0-1868709163-1302003200778';
$lang['utmb'] = '156861353';
$lang['utmc'] = '156861353';
$lang['utmz'] = '156861353.1303465107.4.1.utmccn=(direct)|utmcsr=(direct)|utmcmd=(none)';
?>
